==> decoupled_toolbox-1.3.x-dev.tar.gz: decoupled_toolbox/src/Plugin/Derivative/DecoupledToolboxLocalAction.php <==
<?php

namespace Drupal\decoupled_toolbox\Plugin\Derivative;

use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\Routing\RouteProviderInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;

/**
 * Provides local action definitions for all entity bundles.
 */
class DecoupledToolboxLocalAction extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\RouteProviderInterface
   */
  protected $routeProvider;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  protected $entityTypeBundleInfo;

  /**
   * Constructs a FieldUiLocalAction object.
   *
   * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
   *   The route provider to load routes by name.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(RouteProviderInterface $route_provider, EntityTypeManagerInterface $entity_type_manager, EntityTypeBundleInfoInterface $entityTypeBundleInfo) {
    $this->routeProvider = $route_provider;
    $this->entityTypeManager = $entity_type_manager;
    $this->entityTypeBundleInfo = $entityTypeBundleInfo;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('router.route_provider'),
      $container->get('entity_type.manager'),
      $container->get('entity_type.bundle.info')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $this->derivatives = [];

    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if ($entity_type->get('field_ui_base_route')) {

        $default_options = [
          'title' => $this->t('View decoupled API'),
          'class' => '\Drupal\decoupled_toolbox\Plugin\Menu\RedirectTask',
        ];

        $this->derivatives['decoupled_toolbox_view_' . $entity_type_id . '_display'] = [
            'route_name' => "decoupled_toolbox.entity_decoupled_data.collection",
            'appears_on' => [
              "entity.entity_view_display.{$entity_type_id}.default",
            ],
          ] + $default_options;

        $this->derivatives['decoupled_toolbox_view_' . $entity_type_id . '_display_view_mode'] = [
            'route_name' => "decoupled_toolbox.entity_decoupled_data.collection",
            'appears_on' => [
              "entity.entity_view_display.{$entity_type_id}.view_mode",
            ],
          ] + $default_options;
      }
    }

    foreach ($this->derivatives as &$entry) {
      $entry += $base_plugin_definition;
    }

    return $this->derivatives;
  }

}

==> decoupled_toolbox-1.4.x-dev.tar.gz: decoupled_toolbox/src/Plugin/Derivative/DecoupledToolboxLocalAction.php <==
<?php

namespace Drupal\decoupled_toolbox\Plugin\Derivative;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\Routing\RouteProviderInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\openapi_decoupled_toolbox\OpenapiDecoupledToolboxTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;

/**
 * Provides local action definitions for all entity bundles.
 */
class DecoupledToolboxLocalAction extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\RouteProviderInterface
   */
  protected $routeProvider;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  protected $moduleHandler;

  use OpenapiDecoupledToolboxTrait;

  /**
   * Constructs a FieldUiLocalAction object.
   *
   * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
   *   The route provider to load routes by name.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(RouteProviderInterface $route_provider, EntityTypeManagerInterface $entity_type_manager, ModuleHandlerInterface $module_handler) {
    $this->routeProvider = $route_provider;
    $this->entityTypeManager = $entity_type_manager;
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('router.route_provider'),
      $container->get('entity_type.manager'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $this->derivatives = [];

    $route_name = 'decoupled_toolbox.entity_decoupled_data.collection';
    if ($this->moduleHandler->moduleExists('rest')) {
      $route_name = 'rest.deoupled_toolbox_collection.GET';
    }
    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if ($entity_type->get('field_ui_base_route')) {

        $default_options = [
          'title' => $this->t('View decoupled API'),
        ];

        $this->derivatives['decoupled_toolbox_view_' . $entity_type_id . '_display'] = [
            'route_name' => $route_name,
            'appears_on' => [
              "entity.entity_view_display.{$entity_type_id}.default",
            ],
          ] + $default_options;

        $this->derivatives['decoupled_toolbox_view_' . $entity_type_id . '_display_view_mode'] = [
            'route_name' => $route_name,
            'appears_on' => [
              "entity.entity_view_display.{$entity_type_id}.view_mode",
            ],
          ] + $default_options;
      }
    }

    foreach ($this->derivatives as &$entry) {
      $entry += $base_plugin_definition;
    }

    return $this->derivatives;
  }

}
